#!/usr/bin/env python
# coding: utf-8

import numpy as np

from amrs.misc import latex
import dplume

HEADINGS = ['Species', '5th', '50th', '95th']
SPECIES = [
    r'CO2 (ppm)',
    r'NO2 (10$^{16}$ molec. cm$^{-2}$)',
    r'CO (10$^{17}$ molec. cm$^{-2}$)'
]

def main():

    snr_all = []
    snbr_all = []

    for origin in ['Berlin', 'Janschwalde', 'Lippendorf', 'Turow']:
        signals, bg_means, bg_stds = dplume.vis.plot_signal_and_background(origin)

        # size of neighborhood
        ns = 37 if origin == 'Berlin' else 5

        # prints table showing signal strengths
        print(origin)
        if origin == 'Berlin':
            print(latex.make_table(signals, index=SPECIES, columns=HEADINGS))
        else:
            print(latex.make_table(signals, index=SPECIES, columns=None))

        # signal-to-noise (of median)
        snr = dplume.misc.compute_snrs(signals[:,1], ns, bg_means=bg_means[:,1],
                                       bg_stds=0.0)
        snr_all.append(snr)

        # signal-to-(noise+background) (of median)
        snbr = dplume.misc.compute_snrs(signals[:,1], ns, bg_means=bg_means[:,1],
                                        bg_stds=bg_stds[:,1])

        snbr_all.append(snbr)


        #for ext in ['.png', '.pdf']:
            #img_fname = 'test_%s.%s' % (origin, ext)
            #plt.savefig(img_fname)

    print('Signal-to-noise ratios:')
    print(np.transpose(snr_all).round(1))

    print('Signal-to-noisei+background ratios:')
    print(np.transpose(snbr_all).round(1))


if __name__ == '__main__':
    main()

